==> org-lsst-ccs-subsystem-fcs-gui-5.3.10-sources.jar: org/lsst/ccs/subsystems/fcs/autochanger/ui/InterfaceAutochangerGUI.java <==

package org.lsst.ccs.subsystems.fcs.autochanger.ui;

import static org.lsst.ccs.subsystems.fcs.FCSCst.AC_NAME;
import static org.lsst.ccs.subsystems.fcs.FCSCst.AC_TRUCKS_NAME;
import static org.lsst.ccs.subsystems.fcs.FCSCst.FCSLOG;
import org.lsst.ccs.subsystems.fcs.ui.commons.InterfaceGeneralGUI;

/**
 * 
 * @author virieux
 */
public interface InterfaceAutochangerGUI extends InterfaceGeneralGUI {
   
    long getTimeoutForTrucksMotion();

    long getTimeoutForOnlineClampMotion();

    long getTimeoutForLatchesMotion();

    void setTimeoutForTrucksMotion(long timeout);
    
    void setTimeoutForOnlineClampMotion(long timeout);

    void setTimeoutForLatchesMotion(long timeout);

    
    /**
     ******************************************************************************
     ** Trucks Actions
     * *****************************************************************************
     */
    default void acUpdateTrucksPosition() {
        FCSLOG.info("Autochanger updating Trucks position");
        FCSLOG.info("/timeout=" + UPDATE_POSITION_TIMEOUT);
        sendCommand("updatePosition", UPDATE_POSITION_TIMEOUT, AC_TRUCKS_NAME);
    }

    default void acGoToHandOff() {
        FCSLOG.info("Autochanger Trucks going to Handoff Position");
        FCSLOG.info("/timeout=" + getTimeoutForTrucksMotion());
        sendCommand("goToHandOff", getTimeoutForTrucksMotion(), AC_NAME);
    }

    default void acGoToStandby() {
        FCSLOG.info("Autochanger Trucks going to Standby Position");
        FCSLOG.info("/timeout=" + getTimeoutForTrucksMotion());
        sendCommand("goToStandby", getTimeoutForTrucksMotion(), AC_NAME);
    }

    default void acGoToOnline() {
        FCSLOG.info("Autochanger Trucks going to Online Position");
        FCSLOG.info("/timeout=" + getTimeoutForTrucksMotion());
        sendCommand("goToOnline", getTimeoutForTrucksMotion(), AC_NAME);
    }

    default void acMoveAndClampFilterOnline() {
        FCSLOG.info("Autochanger Trucks moving to Online Position, and clamping");
        FCSLOG.info("/timeout=" + getTimeoutForTrucksMotion());
        sendCommand("moveAndClampFilterOnline", getTimeoutForTrucksMotion(), AC_NAME);
    }

    /**
     ******************************************************************************
     ** end of Trucks Actions
     * *****************************************************************************
     */
    /**
     ******************************************************************************
     ** Clamps Actions
     * *****************************************************************************
     */
    default void unlockOnlineClamps() {
        FCSLOG.info("Autochanger unlocking online clamps");
        sendCommand("unlockClamps", getTimeoutForOnlineClampMotion(), AC_NAME);
    }

    default void lockOnlineClamps() {
        FCSLOG.info("Autochanger locking online clamps");
        sendCommand("lockClamps", getTimeoutForOnlineClampMotion(), AC_NAME);
    }

    default void closeOnlineClamps() {
        FCSLOG.info("Autochanger closing online clamps");
        sendCommand("closeClamps", getTimeoutForOnlineClampMotion(), AC_NAME);
    }

    default void openOnlineClamps() {
        FCSLOG.info("Autochanger opening online clamps");
        sendCommand("openClamps", getTimeoutForOnlineClampMotion(), AC_NAME);
    }

    default void homingOnlineClamp(String clampName) {
        FCSLOG.info("Autochanger homing online clamp: " + clampName);
        sendCommand("openInCurrentModeAndHoming", getTimeoutForOnlineClampMotion(), clampName);
    }

    default void openOnlineClamp(String clampName) {
        FCSLOG.info("Autochanger opening clamp: " + clampName);
        sendCommand("open", getTimeoutForOnlineClampMotion(), clampName);
    }

    default void closeOnlineClamp(String clampName) {
        FCSLOG.info("Autochanger closing clamp: " + clampName);
        sendCommand("close", getTimeoutForOnlineClampMotion(), clampName);
    }

    default void lockOnlineClamp(String clampName) {
        FCSLOG.info("Autochanger clamping clamp: " + clampName);
        sendCommand("lock", getTimeoutForOnlineClampMotion(), clampName);
    }

    default void unlockOnlineClamp(String clampName) {
        FCSLOG.info("Autochanger unclamping clamp: " + clampName);
        sendCommand("unlock", getTimeoutForOnlineClampMotion(), clampName);
    }

    /**
     ******************************************************************************
     ** end of Clamps Actions
     * *****************************************************************************
     */
    /**
     ******************************************************************************
     ** Latches Actions
     * *****************************************************************************
     *
     * @param latchName
     */
    default void closeLatch(String latchName) {
        FCSLOG.info("Autochanger locking latch: " + latchName);
        FCSLOG.info("/timeout=" + getTimeoutForLatchesMotion());
        sendCommand("close", getTimeoutForLatchesMotion(), latchName);
    }

    default void openLatch(String latchName) {
        FCSLOG.info("Autochanger unlocking latch: " + latchName);
        FCSLOG.info("/timeout=" + getTimeoutForLatchesMotion());
        sendCommand("open", getTimeoutForLatchesMotion(), latchName);
    }

    default void closeLatches() {
        FCSLOG.info("Autochanger locking latches.");
        FCSLOG.info("/timeout=" + getTimeoutForLatchesMotion());
        sendCommand("closeLatches", getTimeoutForLatchesMotion(), AC_NAME);
    }

    default void openLatches() {
        FCSLOG.info("Autochanger unlocking latches.");
        FCSLOG.info("/timeout=" + getTimeoutForLatchesMotion());
        sendCommand("openLatches", getTimeoutForLatchesMotion(), AC_NAME);
    }

    /**
     ******************************************************************************
     ** end of Latches Actions
     * *****************************************************************************
     */
    
}

==> org-lsst-ccs-subsystem-fcs-gui-5.4.4-sources.jar: org/lsst/ccs/subsystems/fcs/autochanger/ui/InterfaceAutochangerGUI.java <==

package org.lsst.ccs.subsystems.fcs.autochanger.ui;

import static org.lsst.ccs.subsystems.fcs.FCSCst.AC_NAME;
import static org.lsst.ccs.subsystems.fcs.FCSCst.AC_TRUCKS_NAME;
import static org.lsst.ccs.subsystems.fcs.FCSCst.FCSLOG;
import org.lsst.ccs.subsystems.fcs.ui.commons.InterfaceGeneralGUI;

/**
 * 
 * @author virieux
 */
public interface InterfaceAutochangerGUI extends InterfaceGeneralGUI {
   
    long getTimeoutForTrucksMotion();

    long getTimeoutForOnlineClampMotion();

    long getTimeoutForLatchesMotion();

    void setTimeoutForTrucksMotion(long timeout);
    
    void setTimeoutForOnlineClampMotion(long timeout);

    void setTimeoutForLatchesMotion(long timeout);

    
    /**
     ******************************************************************************
     ** Trucks Actions
     * *****************************************************************************
     */
    default void acUpdateTrucksPosition() {
        FCSLOG.info("Autochanger updating Trucks position");
        FCSLOG.info("/timeout=" + UPDATE_POSITION_TIMEOUT);
        sendCommand("updatePosition", UPDATE_POSITION_TIMEOUT, AC_TRUCKS_NAME);
    }

    default void acAlignSlave() {
        FCSLOG.info("Autochanger aligning slave");
        FCSLOG.info("/timeout=" + getTimeoutForTrucksMotion());
        sendCommand("alignSlave", getTimeoutForTrucksMotion(), AC_NAME);
    }

    default void acGoToHandOff() {
        FCSLOG.info("Autochanger Trucks going to Handoff Position");
        FCSLOG.info("/timeout=" + getTimeoutForTrucksMotion());
        sendCommand("goToHandOff", getTimeoutForTrucksMotion(), AC_NAME);
    }

    default void acGoToStandby() {
        FCSLOG.info("Autochanger Trucks going to Standby Position");
        FCSLOG.info("/timeout=" + getTimeoutForTrucksMotion());
        sendCommand("goToStandby", getTimeoutForTrucksMotion(), AC_NAME);
    }

    default void acGoToOnline() {
        FCSLOG.info("Autochanger Trucks going to Online Position");
        FCSLOG.info("/timeout=" + getTimeoutForTrucksMotion());
        sendCommand("goToOnline", getTimeoutForTrucksMotion(), AC_NAME);
    }

    default void acMoveAndClampFilterOnline() {
        FCSLOG.info("Autochanger Trucks moving to Online Position, and clamping");
        FCSLOG.info("/timeout=" + getTimeoutForTrucksMotion());
        sendCommand("moveAndClampFilterOnline", getTimeoutForTrucksMotion(), AC_NAME);
    }

    /**
     ******************************************************************************
     ** end of Trucks Actions
     * *****************************************************************************
     */
    /**
     ******************************************************************************
     ** Clamps Actions
     * *****************************************************************************
     */
    default void unlockOnlineClamps() {
        FCSLOG.info("Autochanger unlocking online clamps");
        sendCommand("unlockClamps", getTimeoutForOnlineClampMotion(), AC_NAME);
    }

    default void lockOnlineClamps() {
        FCSLOG.info("Autochanger locking online clamps");
        sendCommand("lockClamps", getTimeoutForOnlineClampMotion(), AC_NAME);
    }

    default void closeOnlineClamps() {
        FCSLOG.info("Autochanger closing online clamps");
        sendCommand("closeClamps", getTimeoutForOnlineClampMotion(), AC_NAME);
    }

    default void openOnlineClamps() {
        FCSLOG.info("Autochanger opening online clamps");
        sendCommand("openClamps", getTimeoutForOnlineClampMotion(), AC_NAME);
    }

    default void homingOnlineClamp(String clampName) {
        FCSLOG.info("Autochanger homing online clamp: " + clampName);
        sendCommand("openInCurrentModeAndHoming", getTimeoutForOnlineClampMotion(), clampName);
    }

    default void openOnlineClamp(String clampName) {
        FCSLOG.info("Autochanger opening clamp: " + clampName);
        sendCommand("open", getTimeoutForOnlineClampMotion(), clampName);
    }

    default void closeOnlineClamp(String clampName) {
        FCSLOG.info("Autochanger closing clamp: " + clampName);
        sendCommand("close", getTimeoutForOnlineClampMotion(), clampName);
    }

    default void lockOnlineClamp(String clampName) {
        FCSLOG.info("Autochanger clamping clamp: " + clampName);
        sendCommand("lock", getTimeoutForOnlineClampMotion(), clampName);
    }

    default void unlockOnlineClamp(String clampName) {
        FCSLOG.info("Autochanger unclamping clamp: " + clampName);
        sendCommand("unlock", getTimeoutForOnlineClampMotion(), clampName);
    }

    /**
     ******************************************************************************
     ** end of Clamps Actions
     * *****************************************************************************
     */
    /**
     ******************************************************************************
     ** Latches Actions
     * *****************************************************************************
     *
     * @param latchName
     */
    default void closeLatch(String latchName) {
        FCSLOG.info("Autochanger locking latch: " + latchName);
        FCSLOG.info("/timeout=" + getTimeoutForLatchesMotion());
        sendCommand("close", getTimeoutForLatchesMotion(), latchName);
    }

    default void openLatch(String latchName) {
        FCSLOG.info("Autochanger unlocking latch: " + latchName);
        FCSLOG.info("/timeout=" + getTimeoutForLatchesMotion());
        sendCommand("open", getTimeoutForLatchesMotion(), latchName);
    }

    default void closeLatches() {
        FCSLOG.info("Autochanger locking latches.");
        FCSLOG.info("/timeout=" + getTimeoutForLatchesMotion());
        sendCommand("closeLatches", getTimeoutForLatchesMotion(), AC_NAME);
    }

    default void openLatches() {
        FCSLOG.info("Autochanger unlocking latches.");
        FCSLOG.info("/timeout=" + getTimeoutForLatchesMotion());
        sendCommand("openLatches", getTimeoutForLatchesMotion(), AC_NAME);
    }

    /**
     ******************************************************************************
     ** end of Latches Actions
     * *****************************************************************************
     */
    
}
